@@ -7,13 +7,13 @@ pub struct Options {
     /// Show rustdoc location then exit
     locate: bool,
     #[clap(long, env = "HOST", default_value = "127.0.0.1")]
-    /// Set host.
+    /// Set host
     host: String,
     #[clap(short = 'p', long, env = "PORT", default_value = "8080")]
     /// Set listening port
     port: String,
     #[clap(short = 'o', long)]
-    /// Open in browser. TODO: unimplemented
+    /// Open in browser
     open: bool,
 }
 
@@ -27,20 +27,33 @@ impl Options {
     fn hostport(&self) -> String {
         format!("{}:{}", self.host(), self.port())
     }
+    fn url(&self) -> String {
+        format!("http://{}", self.hostport())
+    }
     fn addr(&self) -> std::net::SocketAddr {
         self.hostport().parse().unwrap()
     }
+    fn open(&self) -> Result<(), anyhow::Error> {
+        if self.open {
+            self.open_browser(self.url())?
+        }
+        Ok(())
+    }
+    fn open_browser<P: AsRef<std::ffi::OsStr>>(&self, path: P) -> Result<(), anyhow::Error> {
+        Ok(opener::open_browser(path)?)
+    }
     pub async fn run(&self) -> Result<(), anyhow::Error> {
-        if self.locate {
+        Ok(if self.locate {
             let dir = lib::find_rustdoc()
                 .unwrap()
                 .into_os_string()
                 .into_string()
                 .unwrap();
-            println!("{}", dir);
-            return Ok(());
-        }
-        println!("Serving rust doc on http://{}", &self.hostport());
-        Ok(lib::serve_rustbook(&self.addr()).await?)
+            println!("{}", dir)
+        } else {
+            println!("Serving rust doc on {}", &self.url());
+            self.open()?;
+            lib::serve_rustbook(&self.addr()).await?
+        })
     }
 }
